@@ -24,7 +24,7 @@
 uint32_t version = 0;
 uint32_t options = BO_BLUR;
 char desc[] = "Gaussian blur (3x3)";
-char dname[] = "Blur gaussian";
+char dname[] = "Gaussian blur";
 
 
 void
