@@ -26,7 +26,7 @@
 uint32_t version = 0;
 uint32_t options = BO_BLUR;
 char desc[] = "Blur filter";
-char dname[] = "Blur horizontal 2";
+char dname[] = "Horizontal blur 2";
 
 
 void
