@@ -20,7 +20,7 @@
 #include "context.h"
 
 uint32_t version = 0;
-uint32_t options = BO_GFX;
+uint32_t options = BO_GFX | BO_SCHEMES;
 enum LayerMode mode = LM_OVERLAY;
 char dname[] = "Galaxy";
 char desc[] = "Galaxy effect";
@@ -174,7 +174,7 @@ free_galaxies(unistruct * gp)
 
 
 static void
-startover()
+startover(void)
 {
   unistruct  *gp = &universe;
   int         i, j; /* more tmp */
@@ -306,6 +306,13 @@ create(Context_t *ctx)
 }
 
 
+void
+on_switch_on(Context_t *ctx)
+{
+  startover();
+}
+
+
 void
 run(Context_t *ctx)
 {
