@@ -22,7 +22,7 @@
 
 
 uint32_t version = 0;
-uint32_t options = BO_GFX|BO_IMAGE;
+uint32_t options = BO_GFX | BO_IMAGE | BO_SCHEMES;
 enum LayerMode mode = LM_NORMAL;
 char desc[] = "Random image squares";
 char dname[] = "Image squares";
