@@ -21,7 +21,7 @@
 
 
 uint32_t version = 0;
-uint32_t options = BO_MIRROR|BO_VER;
+uint32_t options = BO_DISPLACE | BO_MIRROR | BO_VER;
 char dname[] = "Mirror right";
 char desc[] = "Mirror effect";
 
