@@ -32,7 +32,7 @@
  */
 
 uint32_t version = 0;
-uint32_t options = BO_SPLASH|BO_FIRST;
+uint32_t options = BO_SPLASH | BO_FIRST | BO_NORANDOM;
 char desc[] = "Fade previous sequence";
 char dname[] = "Sequence fadeout";
 
@@ -66,7 +66,7 @@ destroy(Context_t *ctx)
 
 
 static void
-splash2()
+splash2(void)
 {
   Pixel_t *p = last->buffer;
 
