@@ -93,7 +93,9 @@ open_mp4(Context_t *ctx)
 
   if (NULL != audio) {
     cmd = g_strdup_printf(MP4_FFMPEG_CMD_AUDIO, max_fps, audio, audio_encoding_rate, mp4_crf, mp4_filename);
+#ifdef DEBUG
     fprintf(stderr, "%s:%s cmd= '%s'\n", __FILE__, __func__, cmd);
+#endif
     xfree(audio);
   } else {
     cmd = g_strdup_printf(MP4_FFMPEG_CMD, max_fps, mp4_crf, mp4_filename);
