@@ -25,7 +25,7 @@ void
 Alarm_init(Alarm_t *a)
 {
   a->delay = (uint16_t)b_rand_uint32_range(a->min, a->max);
-  b_timer_start(a->timer);
+  Timer_start(a->timer);
 }
 
 
@@ -36,7 +36,7 @@ Alarm_new(const int32_t min, const int32_t max)
 
   a = xcalloc(1, sizeof(Alarm_t));
 
-  a->timer = b_timer_new("alarm");
+  a->timer = Timer_new("alarm");
   a->min = min;
   a->max = max;
   assert(a->min <= a->max);
@@ -51,7 +51,7 @@ void
 Alarm_delete(Alarm_t *a)
 {
   if (NULL != a) {
-    b_timer_delete(a->timer);
+    Timer_delete(a->timer);
   }
   xfree(a);
 }
@@ -60,7 +60,7 @@ Alarm_delete(Alarm_t *a)
 int
 Alarm_ring(Alarm_t *a)
 {
-  if (b_timer_elapsed(a->timer) >= (float)a->delay) {
+  if (Timer_elapsed(a->timer) >= (float)a->delay) {
     Alarm_init(a);
     return 1;
   } else {
@@ -72,7 +72,7 @@ Alarm_ring(Alarm_t *a)
 float
 Alarm_elapsed_pct(Alarm_t *a)
 {
-  float elapsed = b_timer_elapsed(a->timer);
+  float elapsed = Timer_elapsed(a->timer);
   uint16_t delay = a->delay;
   float pct;
 
