@@ -32,15 +32,14 @@
 
 void biniou_new(const char *, const char *, const char *, const char *,
                 const uint8_t, const uint32_t, const int);
-void biniou_delete();
+void biniou_delete(void);
 
-/* vla le bordel */
-void biniou_loop();
+void biniou_loop(void);
 void biniou_go(const uint32_t);
-void biniou_run();
-void biniou_start();
-void biniou_end();
-int  biniou_stop();
+void biniou_run(void);
+void biniou_start(void);
+void biniou_end(void);
+int  biniou_stop(void);
 
 void biniou_load_input(const char *, const char *, const double);
 void biniou_set_input(Input_t *);
@@ -52,4 +51,7 @@ void biniou_set_random_mode(const enum RandomMode);
 void biniou_get_delay(const enum RandomDelays, int *, int *);
 void biniou_set_delay(const enum RandomDelays, const int, const int);
 
+// Reports
+void post_session(const char *);
+
 #endif /* __BINIOU_H */
