@@ -181,9 +181,7 @@ typedef struct Context_s {
   Buffer8_t *random;
 
   // Ulfius
-  struct _u_instance instance;
   struct _u_instance vui_instance;
-  struct _u_instance demo_instance;
   GSList *ws_clients;
   pthread_mutex_t ws_clients_mutex;
 
@@ -319,9 +317,6 @@ void Context_stop_ulfius(Context_t *);
 // Vue UI
 void Context_start_vui(Context_t *);
 void Context_stop_vui(Context_t *);
-// Demo websocket
-void Context_start_demo(Context_t *);
-void Context_stop_demo(Context_t *);
 
 json_t *Context_get_state(const Context_t *);
 void Context_websocket_send_colormap(Context_t *);
@@ -346,9 +341,6 @@ void Context_push_video(Context_t *, Buffer8_t *);
 // Timers
 void Context_create_timers(Context_t *);
 
-// Web UI settings
-json_t *Context_settings(const Context_t *ctx);
-
 // UI commands
 void Context_push_command(Context_t *, Command_t *);
 void Context_process_commands(Context_t *);
