@@ -21,6 +21,7 @@
 #include "context.h"
 #include "colormaps.h"
 #include "images.h"
+#include "pthread_utils.h"
 
 
 static void
@@ -42,12 +43,19 @@ Context_display_random(const Context_t *ctx)
 static json_t *
 random_modes_result(const Context_t *ctx)
 {
-  json_t *res = json_object();
-
-  json_object_set_new(res, "random_schemes", json_boolean((ctx->random_mode == BR_SCHEMES) || (ctx->random_mode == BR_BOTH)));
-  json_object_set_new(res, "random_sequences", json_boolean((ctx->random_mode == BR_SEQUENCES) || (ctx->random_mode == BR_BOTH)));
-  json_object_set_new(res, "auto_colormaps", json_boolean(ctx->auto_colormaps));
-  json_object_set_new(res, "auto_images", json_boolean(ctx->auto_images));
+  json_t *res = json_pack("{sb sb sb sb"
+#ifdef WITH_WEBCAM
+                          " sb"
+#endif
+                          "}"
+                          , "randomSchemes", (ctx->random_mode == BR_SCHEMES) || (ctx->random_mode == BR_BOTH),
+                          "randomSequences", (ctx->random_mode == BR_SEQUENCES) || (ctx->random_mode == BR_BOTH),
+                          "autoColormaps", ctx->auto_colormaps,
+                          "autoImages", ctx->auto_images
+#ifdef WITH_WEBCAM
+                          , "autoWebcams", ctx->auto_webcams
+#endif
+                          );
 
   return res;
 }
@@ -75,14 +83,13 @@ Context_command(Context_t *ctx, const enum Command cmd)
       ctx->display_colormap = !ctx->display_colormap;
       break;
 
-    case CMD_APP_FIRST_SEQUENCE:
+    case CMD_APP_FIRST_SEQUENCE: {
 #ifdef DEBUG_COMMANDS
       printf(">>> CMD_APP_FIRST_SEQUENCE\n");
 #endif
       Context_first_sequence(ctx);
-      res = json_object();
-      json_object_set_new(res, "sequence_name", json_string(ctx->sm->cur->name));
-      json_object_set_new(res, "sequence", Sequence_to_json(ctx->sm->cur, 1, 0));
+      res = json_pack("{so}", "sequence", Sequence_to_json(ctx, ctx->sm->cur, 1, 0, ctx->sm->cur->name));
+    }
       break;
 
     case CMD_APP_FREEZE_INPUT:
@@ -94,30 +101,28 @@ Context_command(Context_t *ctx, const enum Command cmd)
       }
       break;
 
-    case CMD_APP_LAST_SEQUENCE:
+    case CMD_APP_LAST_SEQUENCE: {
 #ifdef DEBUG_COMMANDS
       printf(">>> CMD_APP_LAST_SEQUENCE\n");
 #endif
       Context_last_sequence(ctx);
-      res = json_object();
-      json_object_set_new(res, "sequence_name", json_string(ctx->sm->cur->name));
-      json_object_set_new(res, "sequence", Sequence_to_json(ctx->sm->cur, 1, 0));
+      res = json_pack("{so}", "sequence", Sequence_to_json(ctx, ctx->sm->cur, 1, 0, ctx->sm->cur->name));
+    }
       break;
 
     case CMD_APP_LOCK_SELECTED_PLUGIN:
 #ifdef DEBUG_COMMANDS
       printf(">>> CMD_APP_LOCK_SELECTED_PLUGIN\n");
 #endif
-      res = json_object();
-      json_object_set_new(res, "selected_plugin", json_string(plugins->selected->name));
+      res = json_pack("{ss}", "selectedPlugin", plugins->selected->name);
       if (ctx->locked != plugins->selected) {
         ctx->locked = plugins->selected;
-        json_object_set_new(res, "locked_plugin", json_string(ctx->locked->name));
+        json_object_set_new(res, "lockedPlugin", json_string(ctx->locked->name));
 #ifdef DEBUG
         printf("[i] Lock plugin '%s' (%s)\n", ctx->locked->name, plugins->selected->dname);
 #endif
       } else {
-        json_object_set_new(res, "locked_plugin", json_null());
+        json_object_set_new(res, "lockedPlugin", json_null());
 #ifdef DEBUG
         printf("[i] Unlock plugin '%s' (%s)\n", ctx->locked->name, plugins->selected->dname);
 #endif
@@ -145,7 +150,7 @@ Context_command(Context_t *ctx, const enum Command cmd)
           printf("[i] Skipping random schemes since there are no schemes available\n");
           ctx->random_mode = BR_SEQUENCES;
         } else {
-          Schemes_random(ctx);
+          Schemes_random(ctx, 0);
           Alarm_init(ctx->a_random);
         }
       }
@@ -164,14 +169,13 @@ Context_command(Context_t *ctx, const enum Command cmd)
       res = random_modes_result(ctx);
       break;
 
-    case CMD_APP_PREVIOUS_SEQUENCE:
+    case CMD_APP_PREVIOUS_SEQUENCE: {
 #ifdef DEBUG_COMMANDS
       printf(">>> CMD_APP_PREVIOUS_SEQUENCE\n");
 #endif
       Context_previous_sequence(ctx);
-      res = json_object();
-      json_object_set_new(res, "sequence_name", json_string(ctx->sm->cur->name));
-      json_object_set_new(res, "sequence", Sequence_to_json(ctx->sm->cur, 1, 0));
+      res = json_pack("{so}", "sequence", Sequence_to_json(ctx, ctx->sm->cur, 1, 0, ctx->sm->cur->name));
+    }
       break;
 
     case CMD_APP_NEXT_3D_BOUNDARY:
@@ -203,7 +207,7 @@ Context_command(Context_t *ctx, const enum Command cmd)
           printf("[i] Skipping random schemes since there are no schemes available\n");
           ctx->random_mode = BR_BOTH;
         } else {
-          Schemes_random(ctx);
+          Schemes_random(ctx, 0);
           Alarm_init(ctx->a_random);
         }
       }
@@ -212,14 +216,13 @@ Context_command(Context_t *ctx, const enum Command cmd)
       res = random_modes_result(ctx);
       break;
 
-    case CMD_APP_NEXT_SEQUENCE:
+    case CMD_APP_NEXT_SEQUENCE: {
 #ifdef DEBUG_COMMANDS
       printf(">>> CMD_APP_NEXT_SEQUENCE\n");
 #endif
       Context_next_sequence(ctx);
-      res = json_object();
-      json_object_set_new(res, "sequence_name", json_string(ctx->sm->cur->name));
-      json_object_set_new(res, "sequence", Sequence_to_json(ctx->sm->cur, 1, 0));
+      res = json_pack("{so}", "sequence", Sequence_to_json(ctx, ctx->sm->cur, 1, 0, ctx->sm->cur->name));
+    }
       break;
 
 #ifdef WITH_WEBCAM
@@ -235,20 +238,19 @@ Context_command(Context_t *ctx, const enum Command cmd)
       break;
 #endif
 
-    case CMD_APP_RANDOM_SCHEME:
+    case CMD_APP_RANDOM_SCHEME: {
 #ifdef DEBUG_COMMANDS
       printf(">>> CMD_APP_RANDOM_SCHEME\n");
 #endif
       if (NULL != schemes) {
-        Schemes_random(ctx);
+        Schemes_random(ctx, 0);
         Alarm_init(ctx->a_random);
-        res = json_object();
-        json_object_set_new(res, "sequence_name", json_string(UNSAVED_SEQUENCE));
-        json_object_set_new(res, "sequence", Sequence_to_json(ctx->sm->cur, 1, 0));
+        res = json_pack("{so}", "sequence", Sequence_to_json(ctx, ctx->sm->cur, 1, 0, UNSAVED_SEQUENCE));
       }
+    }
       break;
 
-    case CMD_APP_RANDOM_SEQUENCE:
+    case CMD_APP_RANDOM_SEQUENCE: {
 #ifdef DEBUG_COMMANDS
       printf(">>> CMD_APP_RANDOM_SEQUENCE\n");
 #endif
@@ -256,10 +258,9 @@ Context_command(Context_t *ctx, const enum Command cmd)
       if (sequences->size > 1) {
         Context_random_sequence(ctx);
         Alarm_init(ctx->a_random);
-        res = json_object();
-        json_object_set_new(res, "sequence_name", json_string(ctx->sm->cur->name));
-        json_object_set_new(res, "sequence", Sequence_to_json(ctx->sm->cur, 1, 0));
+        res = json_pack("{so}", "sequence", Sequence_to_json(ctx, ctx->sm->cur, 1, 0, ctx->sm->cur->name));
       }
+    }
       break;
 
     case CMD_APP_RANDOMIZE_3D_ROTATIONS:
@@ -294,9 +295,10 @@ Context_command(Context_t *ctx, const enum Command cmd)
       printf(">>> CMD_APP_SET_WEBCAM_REFERENCE\n");
 #endif
       if (ctx->webcams) {
-        xpthread_mutex_lock(&ctx->cam_mtx[ctx->cam]);
-        Buffer8_copy(ctx->cam_save[ctx->cam][0], ctx->cam_ref[ctx->cam]);
-        xpthread_mutex_unlock(&ctx->cam_mtx[ctx->cam]);
+        if (!xpthread_mutex_lock(&ctx->cam_mtx[ctx->cam])) {
+          Buffer8_copy(ctx->cam_save[ctx->cam][0], ctx->cam_ref[ctx->cam]);
+          xpthread_mutex_unlock(&ctx->cam_mtx[ctx->cam]);
+        }
       } else {
         printf("[i] No webcams in use\n");
       }
@@ -367,8 +369,7 @@ Context_command(Context_t *ctx, const enum Command cmd)
         Sequence_changed(ctx->sm->cur);
         Context_update_auto(ctx);
       }
-      res = json_object();
-      json_object_set_new(res, "auto_colormaps", json_boolean(ctx->auto_colormaps));
+      res = json_pack("{sbsb}", "autoColormaps", ctx->auto_colormaps, "autoImages", ctx->auto_images);
       break;
 
     case CMD_APP_TOGGLE_AUTO_IMAGES:
@@ -380,8 +381,7 @@ Context_command(Context_t *ctx, const enum Command cmd)
         Sequence_changed(ctx->sm->cur);
         Context_update_auto(ctx);
       }
-      res = json_object();
-      json_object_set_new(res, "auto_images", json_boolean(ctx->auto_images));
+      res = json_pack("{sbsb}", "autoColormaps", ctx->auto_colormaps, "autoImages", ctx->auto_images);
       break;
 
     case CMD_APP_TOGGLE_3D_ROTATIONS:
@@ -399,7 +399,7 @@ Context_command(Context_t *ctx, const enum Command cmd)
       res = Params3d_to_json(&ctx->params3d);
       break;
 
-    case CMD_APP_TOGGLE_SELECTED_PLUGIN:
+    case CMD_APP_TOGGLE_SELECTED_PLUGIN: {
 #ifdef DEBUG_COMMANDS
       printf(">>> CMD_APP_TOGGLE_SELECTED_PLUGIN\n");
 #endif
@@ -410,14 +410,13 @@ Context_command(Context_t *ctx, const enum Command cmd)
           Context_insert_plugin(ctx, plugins->selected);
         }
       }
-      res = json_object();
-      json_object_set_new(res, "selected_plugin", json_string(plugins->selected->name));
+
+      res = json_pack("{ss so}", "selectedPlugin", plugins->selected->name, "sequence", Sequence_to_json(ctx, ctx->sm->cur, 1, 0, (NULL == ctx->sm->cur->name) ? UNSAVED_SEQUENCE : ctx->sm->cur->name));
       if (NULL != plugins->selected->parameters) {
         json_object_set_new(res, "parameters", plugins->selected->parameters(ctx, NULL, 0));
-        json_object_set_new(res, "selected_param", json_integer(plugins->selected->selected_param));
+        json_object_set_new(res, "selectedParam", json_integer(plugins->selected->selected_param));
       }
-      json_object_set_new(res, "sequence", Sequence_to_json(ctx->sm->cur, 1, 0));
-      json_object_set_new(res, "sequence_name", json_string((NULL == ctx->sm->cur->name) ? UNSAVED_SEQUENCE : ctx->sm->cur->name));
+    }
       break;
 
     case CMD_APP_VOLUME_SCALE_DOWN:
@@ -426,8 +425,7 @@ Context_command(Context_t *ctx, const enum Command cmd)
 #endif
       if (NULL != ctx->input) {
         Input_volume_downscale(ctx->input);
-        res = json_object();
-        json_object_set_new(res, "volume_scale", json_real(ctx->input->volume_scale));
+        res = json_pack("{sf}", "volumeScale", ctx->input->volume_scale);
       }
       break;
 
@@ -437,8 +435,7 @@ Context_command(Context_t *ctx, const enum Command cmd)
 #endif
       if (NULL != ctx->input) {
         Input_volume_upscale(ctx->input);
-        res = json_object();
-        json_object_set_new(res, "volume_scale", json_real(ctx->input->volume_scale));
+        res = json_pack("{sf}", "volumeScale", ctx->input->volume_scale);
       }
       break;
 
@@ -525,18 +522,10 @@ Banks_command(Context_t *ctx, const enum Command cmd)
 
 
 json_t *
-Context_process_command(Context_t *ctx, const enum Command cmd, const void *from, const enum CommandSource source)
+Context_process_command(Context_t *ctx, const enum Command cmd)
 {
   json_t *res = NULL;
 
-  if (source == BC_SDL2) {
-    if ((cmd != CMD_APP_QUIT) && (cmd != CMD_APP_SAVE_QUIT)) {
-      ctx->commands[source]++;
-    }
-  } else {
-    ctx->commands[source]++;
-  }
-
   if ((cmd >= CMD_COL_USE_SHORTCUT_1) && (cmd <= CMD_COL_USE_SHORTCUT_10)) {
     // Shortcuts
     uint8_t shortcut = cmd - CMD_COL_USE_SHORTCUT_1;
@@ -549,8 +538,7 @@ Context_process_command(Context_t *ctx, const enum Command cmd, const void *from
       ctx->sm->cur->cmap_id = id;
       ctx->cf->fader->target = Colormaps_index(id);
       CmapFader_set(ctx->cf);
-      res = json_object();
-      json_object_set_new(res, "colormap", json_string(Colormaps_name(id)));
+      res = json_pack("{ss}", "colormap", Colormaps_name(id));
     }
   } else if ((cmd >= CMD_COL_STORE_SHORTCUT_1) && (cmd <= CMD_COL_STORE_SHORTCUT_10)) {
     uint8_t shortcut = cmd - CMD_COL_STORE_SHORTCUT_1;
@@ -559,9 +547,7 @@ Context_process_command(Context_t *ctx, const enum Command cmd, const void *from
 #endif
     ctx->shortcuts[SH_COLORMAP][shortcut] = ctx->sm->cur->cmap_id;
     Context_save_shortcuts(ctx);
-    res = json_object();
-    json_object_set_new(res, "shortcut", json_integer(shortcut));
-    json_object_set_new(res, "id", json_integer(ctx->shortcuts[SH_COLORMAP][shortcut]));
+    res = json_pack("{si si}", "shortcut", shortcut, "id", ctx->shortcuts[SH_COLORMAP][shortcut]);
   } else if ((cmd >= CMD_IMG_USE_SHORTCUT_1) && (cmd <= CMD_IMG_USE_SHORTCUT_10)) {
     uint8_t shortcut = cmd - CMD_IMG_USE_SHORTCUT_1;
 #ifdef DEBUG_COMMANDS
@@ -573,8 +559,7 @@ Context_process_command(Context_t *ctx, const enum Command cmd, const void *from
       ctx->sm->cur->image_id = id;
       ctx->imgf->fader->target = Images_index(id);
       ImageFader_set(ctx->imgf);
-      res = json_object();
-      json_object_set_new(res, "image", json_string(Images_name(id)));
+      res = json_pack("{ss}", "image", Images_name(id));
     }
   } else if ((cmd >= CMD_IMG_STORE_SHORTCUT_1) && (cmd <= CMD_IMG_STORE_SHORTCUT_10)) {
     uint8_t shortcut = cmd - CMD_IMG_STORE_SHORTCUT_1;
@@ -582,9 +567,7 @@ Context_process_command(Context_t *ctx, const enum Command cmd, const void *from
     printf(">>> CMD_IMG_STORE_SHORTCUT_%d: id= %d\n", shortcut + 1, ctx->sm->cur->image_id);
 #endif
     ctx->shortcuts[SH_IMAGE][shortcut] = ctx->sm->cur->image_id;
-    res = json_object();
-    json_object_set_new(res, "shortcut", json_integer(shortcut));
-    json_object_set_new(res, "id", json_integer(ctx->shortcuts[SH_IMAGE][shortcut]));
+    res = json_pack("{si si}", "shortcut", shortcut, "id", ctx->shortcuts[SH_IMAGE][shortcut]);
     Context_save_shortcuts(ctx);
   } else if ((cmd > START_Application) && (cmd < END_Application)) {
     // Other commands
@@ -607,12 +590,9 @@ Context_process_command(Context_t *ctx, const enum Command cmd, const void *from
   } else if ((cmd > START_Banks) && (cmd < END_Banks)) {
     res = Banks_command(ctx, cmd);
   } else {
-    printf("[!] Unhandled command %d\n", cmd);
-    res = json_object();
-    json_object_set_new(res, "error", json_string("No such command"));
+    fprintf(stderr, "[!] Unhandled command %d\n", cmd);
+    res = json_pack("{ss}", "error", "No such command");
   }
 
-  Context_websocket_send_command_result(ctx, cmd, res, (struct _websocket_manager *)from);
-
   return res;
 }
