@@ -73,6 +73,8 @@ LayerMode_from_string(const char *mode) {
     return LM_INTERLEAVE;
   } else if (is_equal(mode, "random")) {
     return LM_RANDOM;
+  } else if (is_equal(mode, "bandpass")) {
+    return LM_BANDPASS;
   } else {
     printf("[!] Failed to parse mode '%s', setting to NORMAL\n", mode);
 
@@ -121,6 +123,10 @@ LayerMode_to_string(const enum LayerMode mode)
       return "interleave";
       break;
 
+  case LM_BANDPASS:
+    return "bandpass";
+      break;
+
     default:
       xerror("LayerMode_to_string: unknown mode= %d\n", mode);
       break;
@@ -144,11 +150,11 @@ LayerMode_to_OSD_string(const enum LayerMode mode)
 
 
 json_t *
-layer_modes()
+layer_modes(void)
 {
   json_t *array = json_array();
 
-  for (enum LayerMode mode = LM_NONE; mode < NB_LAYER_MODES; ++mode) {
+  for (enum LayerMode mode = LM_NORMAL; mode < LM_NONE; ++mode) {
     json_array_append_new(array, json_string(LayerMode_to_string(mode)));
   }
 
