@@ -73,6 +73,26 @@ do_banner(void)
 }
 
 
+void
+cleanup(void)
+{
+  Settings_delete();
+
+  // command-line
+  // xfree(audio_file); // raises a weird ASan bug
+  xfree(base_dir);
+  xfree(data_dir);
+  xfree(schemes_file);
+  xfree(input_plugin);
+  xfree(output_plugin);
+  xfree(themes);
+#ifdef WITH_WEBCAM
+  xfree(video_base);
+#endif
+  xfree(playlist_filename);
+}
+
+
 int
 main(int argc, char **argv)
 {
@@ -109,13 +129,6 @@ main(int argc, char **argv)
     biniou_load_input(base_dir, input_plugin, volume_scale);
   }
 
-  /* Load output */
-  if (NULL != output_plugin) {
-    context->window_decorations = window_decorations;
-    biniou_load_output(base_dir, output_plugin);
-    biniou_set_full_screen(fullscreen);
-  }
-
   /* Initialize */
   biniou_new(data_dir, base_dir, schemes_file, themes,
              B_INIT_ALL
@@ -162,6 +175,13 @@ main(int argc, char **argv)
     return 0;
   }
 
+  /* Load output */
+  if (NULL != output_plugin) {
+    context->window_decorations = window_decorations;
+    biniou_load_output(base_dir, output_plugin);
+    biniou_set_full_screen(fullscreen);
+  }
+
   biniou_set_random_mode(random_mode);
 
   if (http_port) {
@@ -177,20 +197,7 @@ main(int argc, char **argv)
 
   /* All done */
   biniou_delete();
-  Settings_delete();
-
-  // command-line
-  // xfree(audio_file); // raises a weird ASan bug
-  xfree(base_dir);
-  xfree(data_dir);
-  xfree(schemes_file);
-  xfree(input_plugin);
-  xfree(output_plugin);
-  xfree(themes);
-#ifdef WITH_WEBCAM
-  xfree(video_base);
-#endif
-  xfree(playlist_filename);
+  cleanup();
 
   okdone("Quit: ouh-ouuuuh \\o/");
 
