@@ -71,7 +71,7 @@ stop_capturing(webcam_t *cam)
       type = V4L2_BUF_TYPE_VIDEO_CAPTURE;
 
       if (-1 == xioctl(cam->fd, VIDIOC_STREAMOFF, &type)) {
-        xperror("VIDIOC_STREAMOFF");
+        perror("VIDIOC_STREAMOFF");
       }
 
       break;
